# APRheology
##### _Toolkit for Anton Paar rheometer data_

The purpose of this program is to facilitate the analysis 
of rheometer data of polymeric samples. The program is originally
designed to use RheoCompass csv exports as input, however, it is 
developed without involvement of Anton Paar and is thus independent
from the company and its RheoCompass software. 

##### License

* APRheology is available free of charge under an MIT License. 
See the LICENCE file for more details.


##### Changelog

###### 0.1.2
* Bugfixes

###### 0.1.0
* Initial release



